__v0.0.7 - TBC (not released yet)__  
Add auto-discovery of models

__v0.0.6.3 - 2017-02-26__  
Add migration support    
Enable multiple rich editable fields per page  
Add new summary column 

__v0.0.6.2 - 2017-02-25__  
Fix head partial import bug  
Fix textarea editing in admin forms

__v0.0.6.1 - 2017-02-24__  
Fix macros import bug 

__v0.0.6 - 2017-02-23__  
Add CSS templates / theming  

__v0.0.5 - 2016-12-28__  
Add unit tests  
Add rich text editor

__v0.0.4 - 2016-12-26__  
Update packaging

__v0.0.3 - 2016-12-26__  
Update packaging

__v0.0.2 - 2016-12-26__  
Update documentation

__v0.0.1 - 2016-12-26__  
Initial import